# The HERA Librarian Manual

These files document the Librarian, the data-management system used by the
[HERA Collaboration](http://reionization.org/).

**New users of the Librarian should read [the user’s overview](Overview.md).**


### Contents

- [User’s overview](Overview.md)
- [Accessing the Librarian](Accessing.md)
- [Ingesting new Files](Ingesting.md)
- [Searching for Files, Observations, and Sessions](Searching.md)
- [Staging files to Lustre](Staging.md)
- [Server administrator’s notes](Administration.md)


### Credits

The HERA Librarian has been developed by the HERA Collaborition and is licensed
under the MIT License. The primary author is Peter K. G. Williams.
